import fs from 'node:fs';
import path from 'node:path';

/**
 * 检查文件是否存在
 * @param filePath 文件路径
 * @param checkIsFile 是否检查文件类型 default: false
 * @returns
 */
export const checkFileExists = (filePath: string, checkIsFile = false) => {
  try {
    fs.accessSync(filePath);
    if (checkIsFile) {
      return fs.statSync(filePath).isFile();
    }
    return true;
  } catch (error) {
    return false;
  }
};

/**
 *  检查文件目录是否存在，如果不存在则创建
 * @param filePath 文件路径
 * @param create
 * @returns
 */
export const checkFileDir = (filePath: string, create = true) => {
  const dirPath = path.dirname(filePath);

  const exist = checkFileExists(dirPath);
  if (create && !exist) {
    fs.mkdirSync(dirPath, { recursive: true });
  }
  return exist;
};

export const createDir = (dirPath: string) => {
  if (!checkFileExists(dirPath)) {
    fs.mkdirSync(dirPath, { recursive: true });
  }
  return dirPath;
};
