import { app, assistantConfig } from '@/app.ts';
import { AppDownload } from '@/services/app/index.ts';
import { AssistantApp } from '@/module/assistant/index.ts';
import { shopDefine } from './define.ts';
app
  .route({
    ...shopDefine.get('getRegistry'),
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const registry = assistantConfig.getRegistry();
    assistantConfig.checkMounted();
    ctx.body = registry;
  })
  .addTo(app);

app
  .route({
    ...shopDefine.get('listInstalled'),
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const manager = new AssistantApp(assistantConfig);
    await manager.loadConfig();
    const data = await manager.getPageAndAppList();
    ctx.body = data;
  })
  .addTo(app);

app
  .route({
    ...shopDefine.get('install'),
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    // https://localhost:51015/client/router?path=shop&key=install
    const options = ctx.query?.data || {};
    const { id, type, force, yes } = options;
    assistantConfig.checkMounted();
    const registry = options.registry || assistantConfig.getRegistry();
    // console.log('registry', registry);
    const app = new AppDownload(assistantConfig);
    let info = '';
    if (id) {
      const msg = await app.downloadApp({ id, type, registry, force, yes });
      info = String(msg);
    }
    ctx.body = { info };
  })
  .addTo(app);

app
  .route({
    ...shopDefine.get('uninstall'),
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    // https://localhost:51015/client/router?path=shop&key=uninstall
    const options = ctx.query?.data || {};
    const { id, type, yes } = options;
    const app = new AppDownload(assistantConfig);
    let info = '';
    if (id) {
      const msg = await app.deleteApp({ id, type, yes });
      info = String(msg);
    }
    ctx.body = { info };
  })
  .addTo(app);
